@@ -105,7 +105,7 @@ class GenModel(base.Generative):
         The generated vaule is set at ``self.mu`` and ``self.tau``.
         """
         self.tau = self.rng.gamma(shape=self.h_alpha,scale=1.0/self.h_beta)
-        self.mu = self.rng.normal(loc=self.h_mu,scale=1.0/np.sqrt(self.tau * self.h_kappa))
+        self.mu = self.rng.normal(loc=self.h_m,scale=1.0/np.sqrt(self.tau * self.h_kappa))
         
     def set_params(self,mu,tau):
         """Set the parameter of the sthocastic data generative model.
@@ -493,6 +493,7 @@ class LearnModel(base.Posterior,base.PredictiveMixin):
     
     def get_p_params(self):
         """Get the parameters of the predictive distribution.
+
         Returns
         -------
         p_params : dict of {str: float}
@@ -510,11 +511,13 @@ class LearnModel(base.Posterior,base.PredictiveMixin):
 
     def make_prediction(self,loss="squared"):
         """Predict a new data point under the given criterion.
+
         Parameters
         ----------
         loss : str, optional
             Loss function underlying the Bayes risk function, by default \"squared\".
             This function supports \"squared\", \"0-1\", \"abs\", and \"KL\".
+        
         Returns
         -------
         Predicted_value : {int, numpy.ndarray}
@@ -532,6 +535,7 @@ class LearnModel(base.Posterior,base.PredictiveMixin):
 
     def pred_and_update(self,x,loss="squared"):
         """Predict a new data point and update the posterior sequentially.
+
         Parameters
         ----------
         x : int
@@ -539,6 +543,7 @@ class LearnModel(base.Posterior,base.PredictiveMixin):
         loss : str, optional
             Loss function underlying the Bayes risk function, by default \"squared\".
             This function supports \"squared\", \"0-1\", \"abs\", and \"KL\".
+        
         Returns
         -------
         Predicted_value : {int, numpy.ndarray}
